@@ -55,6 +55,8 @@ static char *program = NULL;
 static int opt_single_shot    = 0;  /* -s */
 static int opt_scripts_too    = 0;  /* -x */
 static int opt_rootdir_check  = 0;  /* -c */
+static int opt_with_workers   = 0;  /* -w */
+static int opt_quiet          = 0;  /* -q */
 
 static char *pidof_root = NULL;
 
@@ -68,6 +70,8 @@ static int __attribute__ ((__noreturn__)) usage(int opt)
 	fputs(USAGE_OPTIONS, fp);
 	fputs(_(" -s, --single-shot         return one PID only\n"), fp);
 	fputs(_(" -c, --check-root          omit processes with different root\n"), fp);
+	fputs(_(" -q,                       quiet mode, only set the exit code\n"), fp);
+	fputs(_(" -w, --with-workers        show kernel workers too\n"), fp);
 	fputs(_(" -x                        also find shells running the named scripts\n"), fp);
 	fputs(_(" -o, --omit-pid <PID,...>  omit processes with PID\n"), fp);
 	fputs(_(" -S, --separator SEP       use SEP as separator put between PIDs"), fp);
@@ -167,9 +171,9 @@ static void select_procs (void)
 			}
 		}
 
-		if (!is_omitted(task.XXXID) && task.cmdline && *task.cmdline) {
+		if (!is_omitted(task.XXXID) && ((task.cmdline && *task.cmdline) || opt_with_workers)) {
 
-			cmd_arg0 = *task.cmdline;
+			cmd_arg0 = (task.cmdline && *task.cmdline) ? *task.cmdline : "\0";
 
 			/* processes starting with '-' are login shells */
 			if (*cmd_arg0 == '-') {
@@ -191,12 +195,14 @@ static void select_procs (void)
 			    !strcmp(program_base, cmd_arg0) ||
 			    !strcmp(program, cmd_arg0) ||
 
+			    (opt_with_workers && !strcmp(program, task.cmd)) ||
+
 			    !strcmp(program, exe_link_base) ||
 			    !strcmp(program, exe_link))
 			{
 				match = 1;
 
-			} else if (opt_scripts_too && *(task.cmdline+1)) {
+			} else if (opt_scripts_too && task.cmdline && *(task.cmdline+1)) {
 
 				cmd_arg1 = *(task.cmdline+1);
 
@@ -289,13 +295,15 @@ int main (int argc, char **argv)
 	int first_pid = 1;
 
 	const char *separator = " ";
-	const char *opts = "scdnxmo:S:?Vh";
+	const char *opts = "scnqxwmo:S:?Vh";
 
 	static const struct option longopts[] = {
 		{"check-root", no_argument, NULL, 'c'},
 		{"single-shot", no_argument, NULL, 's'},
 		{"omit-pid", required_argument, NULL, 'o'},
 		{"separator", required_argument, NULL, 'S'},
+		{"quiet", no_argument, NULL, 'q'},
+		{"with-workers", no_argument, NULL, 'w'},
 		{"help", no_argument, NULL, 'h'},
 		{"version", no_argument, NULL, 'V'},
 		{NULL, 0, NULL, 0}
@@ -312,6 +320,9 @@ int main (int argc, char **argv)
 	/* process command-line options */
 	while ((opt = getopt_long (argc, argv, opts, longopts, NULL)) != -1) {
 		switch (opt) {
+		case 'q':
+			opt_quiet = 1;
+			/* fallthrough */
 		case 's':
 			opt_single_shot = 1;
 			break;
@@ -321,6 +332,9 @@ int main (int argc, char **argv)
 		case 'x':
 			opt_scripts_too = 1;
 			break;
+		case 'w':
+			opt_with_workers = 1;
+			break;
 		case 'c':
 			if (geteuid() == 0) {
 				opt_rootdir_check = 1;
@@ -355,17 +369,21 @@ int main (int argc, char **argv)
 
 		program = argv[optind++];
 
+		if (*program == '\0') continue;
+
 		select_procs();	/* get the list of matching processes */
 
 		if (proc_count) {
 
 			found = 1;
 			for (i = proc_count - 1; i >= 0; i--) {	/* and display their PIDs */
-				if (first_pid) {
-					first_pid = 0;
-					printf ("%ld", (long) procs[i].pid);
-				} else {
-					printf ("%s%ld", separator, (long) procs[i].pid);
+				if (!opt_quiet) {
+					if (first_pid) {
+						first_pid = 0;
+						printf ("%ld", (long) procs[i].pid);
+					} else {
+						printf ("%s%ld", separator, (long) procs[i].pid);
+					}
 				}
 				if (opt_single_shot) break;
 			}
@@ -375,7 +393,7 @@ int main (int argc, char **argv)
 	}
 
 	/* final line feed */
-	if (found) printf("\n");
+	if (!opt_quiet && found) printf("\n");
 
 	/* some cleaning */
 	safe_free(procs);
