@@ -844,7 +844,7 @@ static void fill_cgroup_cvt (const char* directory, proc_t *restrict p) {
         len = snprintf(dst, vMAX, "%s", (dst > dst_buffer) ? "," : "");
         if (len < 0 || len >= vMAX) break;
         dst += len;
-        dst += escape_str(dst, grp, vMAX, &whackable_int);
+        dst += escaped_copy(dst, grp, vMAX, &whackable_int);
     }
     p->cgroup = vectorize_this_str(dst_buffer[0] ? dst_buffer : "-");
 
@@ -862,7 +862,7 @@ static void fill_cmdline_cvt (const char* directory, proc_t *restrict p) {
     int whackable_int = MAX_BUFSZ;
 
     if (read_unvectored(src_buffer, MAX_BUFSZ, directory, "cmdline", ' '))
-        escape_str(dst_buffer, src_buffer, MAX_BUFSZ, &whackable_int);
+        escaped_copy(dst_buffer, src_buffer, MAX_BUFSZ, &whackable_int);
     else
         escape_command(dst_buffer, p, MAX_BUFSZ, &whackable_int, uFLG);
     p->cmdline = vectorize_this_str(dst_buffer);
@@ -876,7 +876,7 @@ static void fill_environ_cvt (const char* directory, proc_t *restrict p) {
 
     dst_buffer[0] = '\0';
     if (read_unvectored(src_buffer, MAX_BUFSZ, directory, "environ", ' '))
-        escape_str(dst_buffer, src_buffer, MAX_BUFSZ, &whackable_int);
+        escaped_copy(dst_buffer, src_buffer, MAX_BUFSZ, &whackable_int);
     p->environ = vectorize_this_str(dst_buffer[0] ? dst_buffer : "-");
 }
 
@@ -910,15 +910,17 @@ static const char *lxc_containers (const char *path) {
            1:cpuset,cpu,cpuacct,devices,freezer,net_cls,blkio,perf_event,net_prio:/lxc/lxc-P
     */
     if (file2str(path, "cgroup", &ub) > 0) {
-        /* ouch, next two defaults could be changed at lxc ./configure time
+        /* ouch, the next defaults could be changed at lxc ./configure time
            ( and a changed 'lxc.cgroup.pattern' is only available to root ) */
-        static const char *lxc_delm1 = "lxc.payload/";    // with lxc-3.1.0
-        static const char *lxc_delm2 = "lxc/";            // thru lxc-3.0.3
+        static const char *lxc_delm1 = "lxc.payload.";    // with lxc-4.0.0
+        static const char *lxc_delm2 = "lxc.payload/";    // thru lxc-3.2.1
+        static const char *lxc_delm3 = "lxc/";            // thru lxc-3.0.3
         const char *delim;
         char *p1;
 
         if ((p1 = strstr(ub.buf, (delim = lxc_delm1)))
-        || ((p1 = strstr(ub.buf, (delim = lxc_delm2))))) {
+        || ((p1 = strstr(ub.buf, (delim = lxc_delm2)))
+        || ((p1 = strstr(ub.buf, (delim = lxc_delm3)))))) {
             static struct lxc_ele {
                 struct lxc_ele *next;
                 const char *name;
