@@ -48,6 +48,10 @@ char *myname;
 
 /* just reports a crash */
 static void signal_handler(int signo){
+  sigset_t ss;
+
+  sigfillset(&ss);
+  sigprocmask(SIG_BLOCK, &ss, NULL);
   if(signo==SIGPIPE) _exit(0);  /* "ps | head" will cause this */
   /* fprintf() is not reentrant, but we _exit() anyway */
   fprintf(stderr,
@@ -65,6 +69,9 @@ static void signal_handler(int signo){
     default:
       error_at_line(0, 0, __FILE__, __LINE__, "%s", _("please report this bug"));
       signal(signo, SIG_DFL);  /* allow core file creation */
+      sigemptyset(&ss);
+      sigaddset(&ss, signo);
+      sigprocmask(SIG_UNBLOCK, &ss, NULL);
       kill(getpid(), signo);
       _exit(EXIT_FAILURE);
   }
@@ -419,6 +426,7 @@ static void prep_forest_sort(void){
     tmp_list = malloc(sizeof(sort_node));
     tmp_list->reverse = 0;
     tmp_list->typecode = '?'; /* what was this for? */
+    tmp_list->pr = incoming->pr;
     tmp_list->sr = incoming->sr;
     tmp_list->need = incoming->need;
     tmp_list->next = sort_list;
@@ -430,6 +438,7 @@ static void prep_forest_sort(void){
   tmp_list = malloc(sizeof(sort_node));
   tmp_list->reverse = 0;
   tmp_list->typecode = '?'; /* what was this for? */
+  tmp_list->pr = incoming->pr;
   tmp_list->sr = incoming->sr;
   tmp_list->need = incoming->need;
   tmp_list->next = sort_list;
@@ -445,7 +454,21 @@ static int compare_two_procs(const void *a, const void *b){
   sort_node *tmp_list = sort_list;
   while(tmp_list){
     int result;
-    result = (*tmp_list->sr)(*(const proc_t *const*)a, *(const proc_t *const*)b);
+    if (tmp_list->sr)
+      result = (*tmp_list->sr)(*(const proc_t *const*)a, *(const proc_t *const*)b);
+    else {
+      /*
+       * Compare by using printing function to "print" the strings
+       * into temporary buffers, then strcmp() can be used to compare
+       * the two results as usual. This is used where direct string
+       * comparison can't be used because the sort key is not directly
+       * in the proc_t structure.
+       */
+      char buf_a[OUTBUF_SIZE], buf_b[OUTBUF_SIZE];
+      (void) (*tmp_list->pr)(buf_a, *(const proc_t *const*)a);
+      (void) (*tmp_list->pr)(buf_b, *(const proc_t *const*)b);
+      result = strcmp(buf_a, buf_b);
+    }
     if(result) return (tmp_list->reverse) ? -result : result;
     tmp_list = tmp_list->next;
   }
@@ -626,6 +649,7 @@ int main(int argc, char *argv[]){
   setlocale (LC_ALL, "");
   bindtextdomain(PACKAGE, LOCALEDIR);
   textdomain(PACKAGE);
+  setenv("TZ", ":/etc/localtime", 0);
 
 #ifdef DEBUG
   init_stack_trace(argv[0]);
