@@ -350,7 +350,7 @@ static void build_norm_nlstab (void) {
    Norm_nlstab[OFF_one_word_txt] = _("Off");
 /* Translation Hint: Only the following words should be translated
    .                 secs (seconds), max (maximum), user, field, cols (columns)*/
-   Norm_nlstab[USAGE_abbrev_txt] = _(" -hv | -bcEHiOSs1 -d secs -n max -u|U user -p pid(s) -o field -w [cols]");
+   Norm_nlstab[USAGE_abbrev_txt] = _(" -hv | -bcEeHiOSs1 -d secs -n max -u|U user -p pid(s) -o field -w [cols]");
    Norm_nlstab[FAIL_statget_txt] = _("failed /proc/stat read");
    Norm_nlstab[FOREST_modes_fmt] = _("Forest mode %s");
    Norm_nlstab[FAIL_tty_get_txt] = _("failed tty get");
@@ -413,11 +413,11 @@ static void build_norm_nlstab (void) {
    Norm_nlstab[WORD_process_txt] = _("Tasks");
 /* Translation Hint: The following "word" is meant to represent either a single
    .                 cpu or all of the processors in a multi-processor computer
-   .                 (should be exactly 6 characters, not counting the colon)*/
-   Norm_nlstab[WORD_allcpus_txt] = _("Cpu(s):");
+   .                 (should be exactly 6 characters, excluding leading % & colon) */
+   Norm_nlstab[WORD_allcpus_txt] = _("%Cpu(s):");
 /* Translation Hint: The following "word" is meant to represent a single processor
-   .                 (should be exactly 3 characters) */
-   Norm_nlstab[WORD_eachcpu_fmt] = _("Cpu%-3d:");
+   .                 (should be exactly 3 characters, excluding leading %%, fmt chars & colon) */
+   Norm_nlstab[WORD_eachcpu_fmt] = _("%%Cpu%-3d:");
 /* Translation Hint: The following word "another" must have 1 trailing space */
    Norm_nlstab[WORD_another_txt] = _("another ");
    Norm_nlstab[FIND_no_next_txt] = _("Locate next inactive, use \"L\"");
@@ -487,8 +487,9 @@ static void build_norm_nlstab (void) {
    Norm_nlstab[WORD_exclude_txt] = _("exclude");
    Norm_nlstab[OSEL_statlin_fmt] = _("<Enter> to resume, filters: %s");
    Norm_nlstab[WORD_noneone_txt] = _("none");
-/* Translation Hint: The following word 'Node' should be exactly 4 characters */
-   Norm_nlstab[NUMA_nodenam_fmt] = _("Node%-2d:");
+/* Translation Hint: The following word 'Node' should be exactly
+                     4 characters, excluding leading %%, fmt chars & colon) */
+   Norm_nlstab[NUMA_nodenam_fmt] = _("%%Node%-2d:");
    Norm_nlstab[NUMA_nodeget_fmt] = _("expand which node (0-%d)");
    Norm_nlstab[NUMA_nodebad_txt] = _("invalid node");
    Norm_nlstab[NUMA_nodenot_txt] = _("sorry, NUMA extensions unavailable");
@@ -500,6 +501,9 @@ static void build_norm_nlstab (void) {
    Norm_nlstab[WORD_abv_swp_txt] = _("Swap");
    Norm_nlstab[BAD_memscale_fmt] = _("bad memory scaling arg '%c'");
    Norm_nlstab[XTRA_vforest_fmt] = _("PID to collapse/expand [default pid = %d]");
+   Norm_nlstab[XTRA_size2up_txt] = _("terminal is not wide enough");
+   Norm_nlstab[XTRA_modebad_txt] = _("wrong mode, command inactive");
+   Norm_nlstab[XTRA_warnold_txt] = _("saving prevents older top from reading, save anyway?");
 }
 
 
@@ -549,8 +553,8 @@ static void build_uniq_nlstab (void) {
       "Window ~1%s~6: ~1Cumulative mode ~3%s~2.  ~1System~6: ~1Delay ~3%.1f secs~2; ~1Secure mode ~3%s~2.\n"
       "\n"
       "  Z~5,~1B~5,E,e   Global: '~1Z~2' colors; '~1B~2' bold; '~1E~2'/'~1e~2' summary/task memory scale\n"
-      "  l,t,m     Toggle Summary: '~1l~2' load avg; '~1t~2' task/cpu stats; '~1m~2' memory info\n"
-      "  0,1,2,3,I Toggle: '~10~2' zeros; '~11~2/~12~2/~13~2' cpus or numa node views; '~1I~2' Irix mode\n"
+      "  l,t,m,I   Toggle: '~1l~2' load avg; '~1t~2' task/cpu; '~1m~2' memory; '~1I~2' Irix mode\n"
+      "  0,1,2,3,4 Toggle: '~10~2' zeros; '~11~2/~12~2/~13~2' cpu/numa views; '~14~2' cpus two abreast\n"
       "  f,F,X     Fields: '~1f~2'/'~1F~2' add/remove/order/sort; '~1X~2' increase fixed-width\n"
       "\n"
       "  L,&,<,> . Locate: '~1L~2'/'~1&~2' find/again; Move sort column: '~1<~2'/'~1>~2' left/right\n"
@@ -563,19 +567,12 @@ static void build_uniq_nlstab (void) {
       "  V,v     . Toggle: '~1V~2' forest view; '~1v~2' hide/show forest view children\n"
       "\n"
       "%s"
-      "  W,Y       Write configuration file '~1W~2'; Inspect other output '~1Y~2'\n"
+      "  W,Y,!     Write config file '~1W~2'; Inspect other output '~1Y~2'; Combine Cpus '~1!~2'\n"
       "  q         Quit\n"
       "          ( commands shown with '.' require a ~1visible~2 task display ~1window~2 ) \n"
       "Press '~1h~2' or '~1?~2' for help with ~1Windows~2,\n"
       "Type 'q' or <Esc> to continue ");
 
-/* Translation Hint: As is true for the text above, the "keys" shown to the left and
-   .                 also imbedded in the translatable text (along with escape seqs)
-   .                 should never themselves be translated. */
-   Uniq_nlstab[KEYS_helpext_fmt] = _(""
-      "  k,r       Manipulate tasks: '~1k~2' kill; '~1r~2' renice\n"
-      "  d or s    Set update interval\n");
-
    Uniq_nlstab[WINDOWS_help_fmt] = _(""
       "Help for Windows / Field Groups~2 - \"Current Window\" = ~1 %s ~6\n"
       "\n"
@@ -637,6 +634,13 @@ static void build_uniq_nlstab (void) {
       "   'q' or <Esc> to abort changes to window '~1%s~2'\n"
       "   'a' or 'w' to commit & change another, <Enter> to commit and end ");
 
+/* Translation Hint: As is true for the text above, the "keys" shown to the left and
+   .                 also imbedded in the translatable text (along with escape seqs)
+   .                 should never themselves be translated. */
+   Uniq_nlstab[KEYS_helpext_fmt] = _(""
+      "  k,r       Manipulate tasks: '~1k~2' kill; '~1r~2' renice\n"
+      "  d or s    Set update interval\n");
+
 /* Translation Hint:
    .  This Fields Management header should be 3 lines long so as
    .  to allow 1 blank line before the fields & descriptions.
@@ -653,23 +657,23 @@ static void build_uniq_nlstab (void) {
    Uniq_nlstab[STATE_line_1_fmt] = _("%s:~3"
       " %3u ~2total,~3 %3u ~2running,~3 %3u ~2sleeping,~3 %3u ~2stopped,~3 %3u ~2zombie~3\n");
 
-   Uniq_nlstab[STATE_lin2x4_fmt] = _("%%%s~3"
-      " %#5.1f  ~2user,~3 %#5.1f  ~2system,~3 %#5.1f  ~2nice,~3 %#5.1f  ~2idle~3\n");
+   Uniq_nlstab[STATE_lin2x4_fmt] = _("%s~3"
+      " %#5.1f  ~2user,~3 %#5.1f  ~2system,~3 %#5.1f  ~2nice,~3 %#5.1f  ~2idle~3");
 
-   Uniq_nlstab[STATE_lin2x5_fmt] = _("%%%s~3"
-      " %#5.1f  ~2user,~3 %#5.1f  ~2system,~3 %#5.1f  ~2nice,~3 %#5.1f  ~2idle,~3 %#5.1f  ~2IO-wait~3\n");
+   Uniq_nlstab[STATE_lin2x5_fmt] = _("%s~3"
+      " %#5.1f  ~2user,~3 %#5.1f  ~2system,~3 %#5.1f  ~2nice,~3 %#5.1f  ~2idle,~3 %#5.1f  ~2IO-wait~3");
 
 /* Translation Hint: Only the following abbreviations need be translated
    .                 us = user, sy = system, ni = nice, id = idle, wa = wait,
    .                 hi hardware interrupt, si = software interrupt */
-   Uniq_nlstab[STATE_lin2x6_fmt] = _("%%%s~3"
-      " %#5.1f ~2us,~3 %#5.1f ~2sy,~3 %#5.1f ~2ni,~3 %#5.1f ~2id,~3 %#5.1f ~2wa,~3 %#5.1f ~2hi,~3 %#5.1f ~2si~3\n");
+   Uniq_nlstab[STATE_lin2x6_fmt] = _("%s~3"
+      " %#5.1f ~2us,~3 %#5.1f ~2sy,~3 %#5.1f ~2ni,~3 %#5.1f ~2id,~3 %#5.1f ~2wa,~3 %#5.1f ~2hi,~3 %#5.1f ~2si~3");
 
 /* Translation Hint: Only the following abbreviations need be translated
    .                 us = user, sy = system, ni = nice, id = idle, wa = wait,
    .                 hi hardware interrupt, si = software interrupt, st = steal time */
-   Uniq_nlstab[STATE_lin2x7_fmt] = _("%%%s~3"
-      "%#5.1f ~2us,~3%#5.1f ~2sy,~3%#5.1f ~2ni,~3%#5.1f ~2id,~3%#5.1f ~2wa,~3%#5.1f ~2hi,~3%#5.1f ~2si,~3%#5.1f ~2st~3\n");
+   Uniq_nlstab[STATE_lin2x7_fmt] = _("%s~3"
+      "%#5.1f ~2us,~3%#5.1f ~2sy,~3%#5.1f ~2ni,~3%#5.1f ~2id,~3%#5.1f ~2wa,~3%#5.1f ~2hi,~3%#5.1f ~2si,~3%#5.1f ~2st~3");
 
 /* Translation Hint: this must be translated as 2 lines with words above & below aligned */
    Uniq_nlstab[MEMORY_lines_fmt] = _(""
