@@ -194,13 +194,13 @@ static void new_header(void)
 	const char *header =
 	    _("procs -----------memory---------- ---swap-- -----io---- -system-- ------cpu-----");
 	const char *wide_header =
-	    _("procs -----------------------memory---------------------- ---swap-- -----io---- -system-- --------cpu--------");
+	    _("--procs-- -----------------------memory---------------------- ---swap-- -----io---- -system-- --------cpu--------");
 	const char *timestamp_header = _(" -----timestamp-----");
 
 	const char format[] =
 	    "%2s %2s %6s %6s %6s %6s %4s %4s %5s %5s %4s %4s %2s %2s %2s %2s %2s";
 	const char wide_format[] =
-	    "%2s %2s %12s %12s %12s %12s %4s %4s %5s %5s %4s %4s %3s %3s %3s %3s %3s";
+	    "%4s %4s %12s %12s %12s %12s %4s %4s %5s %5s %4s %4s %3s %3s %3s %3s %3s";
 
 
 	printf("%s", w_option ? wide_header : header);
@@ -281,7 +281,7 @@ static void new_format(void)
 	const char format[] =
 	    "%2u %2u %6lu %6lu %6lu %6lu %4u %4u %5u %5u %4u %4u %2u %2u %2u %2u %2u";
 	const char wide_format[] =
-	    "%2u %2u %12lu %12lu %12lu %12lu %4u %4u %5u %5u %4u %4u %3u %3u %3u %3u %3u";
+	    "%4u %4u %12lu %12lu %12lu %12lu %4u %4u %5u %5u %4u %4u %3u %3u %3u %3u %3u";
 
 	unsigned int tog = 0;	/* toggle switch for cleaner code */
 	unsigned int i;
